@@ -22,6 +22,7 @@ from flex.utils import (
     get_type_for_value,
     chain_reduce_partial,
     cast_value_to_type,
+    deep_equal,
 )
 from flex.paths import (
     match_path_to_api_path,
@@ -36,26 +37,13 @@ from flex.constants import (
 )
 from flex.decorators import (
     skip_if_not_of_type,
+    skip_if_empty,
     suffix_reserved_words,
     translate_validation_error,
 )
 from flex.error_messages import MESSAGES
 
 
-def skip_if_empty(func):
-    """
-    Decorator for validation functions which makes them pass if the value
-    passed in is the EMPTY sentinal value.
-    """
-    @functools.wraps(func)
-    def inner(value, *args, **kwargs):
-        if value is EMPTY:
-            return
-        else:
-            return func(value, *args, **kwargs)
-    return inner
-
-
 @skip_if_empty
 def validate_type(value, types):
     """
@@ -289,17 +277,6 @@ def generate_pattern_validator(pattern, **kwargs):
     return functools.partial(validate_pattern, regex=re.compile(pattern))
 
 
-def deep_equal(a, b):
-    """
-    Because of things in python like:
-        >>> 1 == 1.0
-        True
-        >>> 1 == True
-        True
-    """
-    return a == b and isinstance(a, type(b)) and isinstance(b, type(a))
-
-
 @skip_if_empty
 def validate_enum(value, options):
     if not any(deep_equal(value, option) for option in options):
